asdf_ndarray_read_tile_ndim

Function asdf_ndarray_read_tile_ndim 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn asdf_ndarray_read_tile_ndim( ndarray: *mut asdf_ndarray_t, origin: *const u64, shape: *const u64, dst_t: ScalarTypeAbi, dst: *mut *mut c_void, ) -> NdarrayErr
Read an N-dimensional tile, converting to dst_t.

Safety

origin and shape must each point to ndim values; dst must be writable, pointing either at storage large enough for the tile or at a null pointer, in which case a buffer is allocated for the caller to free.