#[unsafe(no_mangle)]pub unsafe extern "C" fn asdf_parser_error_errno(
parser: *const AsdfParser,
) -> c_intExpand description
The recorded errno, meaningful only for a system error.
Safety
parser must be null or a valid handle.
#[unsafe(no_mangle)]pub unsafe extern "C" fn asdf_parser_error_errno(
parser: *const AsdfParser,
) -> c_intThe recorded errno, meaningful only for a system error.
parser must be null or a valid handle.