asdf_parser_parse

Function asdf_parser_parse 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn asdf_parser_parse( parser: *mut AsdfParser, ) -> *mut AsdfEvent
Produce the next event, or null at the end of the stream.

The caller owns the event and releases it with asdf_event_free.

Safety

parser must be null or a valid handle.