Function asdf_value_is_ndarray
Source #[unsafe(no_mangle)]
pub unsafe extern "C" fn asdf_value_is_ndarray(
value: *mut AsdfValue,
) -> bool
Whether a value is an ndarray, by its tag.
Safety
value must be null or a valid value handle.