#[unsafe(no_mangle)]pub unsafe extern "C" fn asdf_parser_parse(
parser: *mut AsdfParser,
) -> *mut AsdfEventExpand description
Produce the next event, or null at the end of the stream.
The caller owns the event and releases it with asdf_event_free.
Safety
parser must be null or a valid handle.